@@ -54,12 +54,14 @@ def negADJ(neg_words,adjDEL):
 
 
 
-def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,nncompound = False,):
+def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,nncompound = False,facility = False,faciNN = False):
   """
   include_otherEdge: greedy edges of the unmatched adj, verb, noun 
   only_otherNouns: does not have adjverb in other2N_edges other than av2n, the other2N_edeges are greedy to mach the rest adj, verb, noun instead of considering match pattern
   nounDEL : nouns to be removed 
   adjDEL : adjective to be removed 
+  facility: additional noun for the missing in the include_otherEdge class, e.g. I recommend! So pretty! 
+  faciNN: add facility noun to NN edges, otherwise facility only add to AV2N in the otherEdges other than facilty-N in the matched AV2N to form greedy NN 
   """
   non_opi_adjs = negADJ(neg_words,adjDEL)
   
@@ -91,6 +93,12 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
   if verbose_text:
     print('text1 clean:', text1)
 
+  if facility:
+    facility1 = facility +'2nnn' 
+    print('facility1:',facility1)
+    mapnoun(facility1)
+
+
   # 2. quote,hyphen, entity, n't
 
   # quote 
@@ -358,17 +366,41 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
   else:
     noadjNV = text6
 
-  noadjNV2 = []
+  print('noadjNV',noadjNV)
+  noadjV = []
+  noN =[]
   for token in nlp(noadjNV):
-    if token.pos_ in ['ADJ','NOUN','VERB']:
-        noadjNV2.append(token.text)
+    if token.pos_ in ['ADJ','VERB']:
+        noadjV.append(token.text)
+    elif token.pos_ == 'NOUN':
+        noN.append(token.text)
+  noadjNV2 = noadjV + noN 
   noadjNV3 = " ".join(noadjNV2)
   if verbose:
     print('noadjNV3:' ,noadjNV3)
-  other2N_edges, otherNN_edges = av2Nedge([noadjNV3])
+  
+  if facility: 
+    other2N_edges = []
+    otherNN_edges = []
+    for av in noadjV: # av other than av in av2n 
+      if av != 'be':
+        other2n_edge = [av,facility1]
+        other2N_edges.append(other2n_edge)
+    for n in noN: # n other than n in av2n 
+      if n != 'be':
+        otherNN_edge = (n,facility1)
+        otherNN_edges.append(otherNN_edge) 
+  else:
+     other2N_edges, otherNN_edges = av2Nedge([noadjNV3])
 
   ## --- 3 all noun to noun set ---
   allnouns = []
+  if faciNN and facility:
+    text5 = text5 +" " + facility1
+    print('faciNN', text5)
+  else:
+    text5 = text5
+    
   for token in nlp(text5):
     if token.pos_ == 'NOUN' and token.text != 'be':  # in case be changed as noun
       #print(token.text)
